# Smart Enums

Smart Enums is a small package to provide comfort enums from other languages like Rust, Haskell or Elm.

There are currently two enums included. The `Result` and `Some` enum.
Additional enums and functionality will be added in the future. This package is currently mostly for personal use but maybe someone else has use cases for it too. :blush: :relaxed:
